## If the required library is not installed, install it.
#install.packages("BiocManager")
#library(BiocManager)
#BiocManager::install("DESeq2")
#BiocManager::install("mixOmics")
#BiocManager::install("ggplot2")
#BiocManager::install("RColorBrewer")

library("DESeq2")
library("mixOmics")
library("ggplot2")
library("RColorBrewer")

## Modify the following contents according to the working directory and analysis data.
sampleTitle <- "lowFe"
workDirectory <- "C:\\scratch\\"
control <- "lowFe-WT"
treat <- "lowFe-cir1"

## Data loading and DeSeq2 analysis
sampleInfo <- read.table(paste(workDirectory, "sample_info_", sampleTitle, ".txt", sep = ""), sep = "\t", header = TRUE)
countData <- read.table(paste(workDirectory, "count_", sampleTitle, ".txt", sep = ""), sep = "\t", row.names = 1, header = TRUE)

dds <- DESeqDataSetFromMatrix(
  countData = countData,
  colData = sampleInfo,
  design = ~ type
)

dds <- DESeq(dds)
res <- results(dds, contrast = c("type", treat, control))
mcols(res, use.names=TRUE)

## plotMA, plotDispersion, p-value histogram
pdf(file = paste(workDirectory, "Plot_", control, "_vs_", treat, ".pdf", sep = ""), paper='A4r')

plotMA(res, colNonSig = "gray32", colSig = "gray32", ylim = c(-5, 5))
with(subset(res, (log2FoldChange > 1) & (baseMean > 1) & (pvalue < 0.05)), {
  points(baseMean, log2FoldChange, col = "red", pch = 1)
})
with(subset(res, (log2FoldChange < -1) & (baseMean > 1) & (pvalue < 0.05)), {
  points(baseMean, log2FoldChange, col = "red", pch = 1)
})
nrow(subset(res, (log2FoldChange > 1) & (baseMean > 1) & (pvalue < 0.05)))
nrow(subset(res, (log2FoldChange < -1) & (baseMean > 1) & (pvalue < 0.05)))

plotDispEsts(dds, ylim = c(1e-6, 1e1))

hist(res$pvalue, breaks = 20, col = "grey")

## plotPCA
dds <- estimateSizeFactors(dds)
se <- SummarizedExperiment(log2(counts(dds, normalized=TRUE) + 1), colData=colData(dds))
plotPCA(DESeqTransform(se), intgroup = "type")

## sample heatmap
sampleDists <- as.matrix(dist(t(log2(counts(dds, normalized=TRUE) + 1))))
cimColor <- colorRampPalette(rev(brewer.pal(9, "Blues")))(16)
cim(sampleDists, color = cimColor, symkey=FALSE)

dev.off()

# totalTable with normalized counts
normalized.counts <- as.data.frame(counts(dds, normalized=TRUE))
totalTable <- cbind(res, normalized.counts)
write.table(as.data.frame(totalTable), file = paste(workDirectory, "total_", sampleTitle, "_", control, "_vs_", treat, ".tsv", sep = ""), quote = FALSE, sep = "\t", col.names = NA)
